﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections;
using System.Data;
using System.ComponentModel;
using Microsoft.Practices.Prism.ViewModel;
using Infragistics.Controls.Grids;

namespace ListOfArraysAsDataSource
{
    public class CellValue : NotificationObject
    {
        private int val;
        public int Value 
        {
            get { return val; }
            set
            {
                if (value == val) return;
                val = value;
                RaisePropertyChanged(() => Value);
            }
        }

        private string colour;
        public string Colour 
        {
            get { return colour; }
            set
            {
                if (value == colour) return;
                colour = value;
                RaisePropertyChanged(() => Colour);
            }
        }

        private string tooltip;
        public string ToolTip
        {
            get { return tooltip; }
            set
            {
                if (value == tooltip) return;
                tooltip = value;
                RaisePropertyChanged(() => ToolTip);
            }
        }
    }

    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private int columns = 5;
        private int rows = 5;
        private DataTable table;
        private DataView view;

        public MainWindow()
        {
            InitializeComponent();

            InitXamGrid(columns);

            table = new DataTable();
            GenerateTable(columns, rows);
            view = table.DefaultView;
            
            view.AllowEdit = true;

            xamDataGrid1.ItemsSource = view;

        }

        private void GenerateTable(int columns, int rows)
        {
            Random r = new Random();

            for (int i = 1; i <= columns; i++)
            {
                table.Columns.Add(i.ToString(), typeof(CellValue));
            }

            for (int i = 0; i < rows; i++)
            {
                CellValue[] row = new CellValue[columns];
                for (int j = 0; j < columns; j++)
                {
                    var cell = new CellValue { Value = r.Next(100000, 1000000) };
                    switch(r.Next(2))
                    {
                        case 0:
                            cell.Colour = "red";
                            break;
                        case 1:
                            cell.Colour = "black";
                            break;
                        default:
                            break;
                            
                    }
                    row[j] = cell;
                }
                table.Rows.Add(row);
            }
        }

        private void InitXamGrid(int columns)
        {
            for (int i = 1; i <= columns; i++)
            {
                var columnTemplate = xamDataGrid1.Resources["ColumnTemplate"] as DataTemplate;

                TemplateColumn col = new TemplateColumn { Key = i.ToString(), 
                                                          ItemTemplate = columnTemplate, 
                                                          HeaderTextHorizontalAlignment = HorizontalAlignment.Center};
                xamDataGrid1.Columns.Add(col);
            }
        }

        private void OnModifyData(object sender, RoutedEventArgs e)
        {
            Random r = new Random((int)DateTime.Now.Ticks);

            foreach (DataRow row in table.Rows)
            {
                row.BeginEdit();
                foreach (var value in row.ItemArray)
                {
                    var cellValue = value as CellValue;
                    if (cellValue != null)
                    {
                        cellValue.Value = r.Next(100000);
                        switch (r.Next(2))
                        {
                            case 0:
                                cellValue.Colour = "red";
                                break;
                            case 1:
                                cellValue.Colour = "black";
                                break;
                            default:
                                break;

                        }

                    }
                }
                row.EndEdit();
            }
        }

        private void OnClearSelection(object sender, MouseButtonEventArgs e)
        {
            xamDataGrid1.SelectionSettings.SelectedCells.Clear();
            xamDataGrid1.SelectionSettings.SelectedRows.Clear();
        }
    }
}
